@@ -1,7 +1,7 @@
 ### R code from vignette source 'rebmix.Rnw'
 
 ###################################################
-### code chunk number 1: rebmix-code
+### code chunk number 1: rebmix-code-0
 ###################################################
 ##############################################
 ## R sources for reproducing the results in ##
@@ -13,7 +13,7 @@ options(prompt = "R> ", continue = "+  ", width = 80,
 
 
 ###################################################
-### code chunk number 2: rebmix-code
+### code chunk number 2: rebmix-code-1
 ###################################################
 ###################
 ## Preliminaries ##
@@ -26,7 +26,7 @@ devAskNewPage(ask = TRUE)
 
 
 ###################################################
-### code chunk number 3: rebmix-code
+### code chunk number 3: rebmix-code-2
 ###################################################
 ######################
 ##  Gamma datasets  ##
@@ -63,7 +63,7 @@ gamma3 <- RNGMIX(Dataset.name = "gamma3", rseed = -4, n = n, Theta = a.Theta(The
 
 
 ###################################################
-### code chunk number 4: rebmix-code
+### code chunk number 4: rebmix-code-3
 ###################################################
 ## Estimate number of components, component weights and component parameters.
 
@@ -90,11 +90,11 @@ gamma3est <- REBMIX(Dataset = a.Dataset(gamma3),
 ###################################################
 ### code chunk number 5: gamma3-fig
 ###################################################
-plot(gamma3est, pos = 1, what = c("pdf", "marginal cdf"), ncol = 2, npts = 1000)
+plot(gamma3est, pos = 1, what = c("pdf", "marginal cdf"), ncol = 2, npts = 1000, family = "sans")
 
 
 ###################################################
-### code chunk number 6: rebmix-code
+### code chunk number 6: rebmix-code-4
 ###################################################
 summary(gamma2est)
 
@@ -104,7 +104,7 @@ a.theta2.all(gamma1est, pos = 1)
 
 
 ###################################################
-### code chunk number 7: rebmix-code
+### code chunk number 7: rebmix-code-5
 ###################################################
 ## Bootstrap finite mixture.
 
@@ -116,7 +116,7 @@ summary(gamma3boot)
 
 
 ###################################################
-### code chunk number 8: rebmix-code
+### code chunk number 8: rebmix-code-6
 ###################################################
 ## EM.control object creation.
 
@@ -159,7 +159,7 @@ summary(gamma3est.em)
 
 
 ###################################################
-### code chunk number 9: rebmix-code
+### code chunk number 9: rebmix-code-7
 ###################################################
 #########################
 ##   Poisson dataset   ##
@@ -179,7 +179,7 @@ poisson <- RNGMIX(Dataset.name = paste("Poisson_", 1:10, sep = ""), n = n, Theta
 
 
 ###################################################
-### code chunk number 10: rebmix-code
+### code chunk number 10: rebmix-code-8
 ###################################################
 ## Estimate number of components, component weights and component parameters.
 
@@ -194,7 +194,7 @@ poissonest <- REBMIX(Dataset = a.Dataset(poisson),
 ###################################################
 ### code chunk number 11: poisson-fig
 ###################################################
-plot(poissonest, pos = 1, what = c("pdf", "marginal pdf", "IC", "D", "logL"), nrow = 2, ncol = 3, npts = 1000)
+plot(poissonest, pos = 1, what = c("pdf", "marginal pdf", "IC", "D", "logL"), nrow = 2, ncol = 3, npts = 1000, family = "sans")
 
 
 ###################################################
@@ -202,11 +202,11 @@ plot(poissonest, pos = 1, what = c("pdf", "marginal pdf", "IC", "D", "logL"), nr
 ###################################################
 poissonclu <- RCLRMIX(x = poissonest, pos = 1, Zt = a.Zt(poisson))
 
-plot(poissonclu)
+plot(poissonclu, family = "sans")
 
 
 ###################################################
-### code chunk number 13: rebmix-code
+### code chunk number 13: rebmix-code-9
 ###################################################
 ## Visualize results.
 
@@ -218,7 +218,7 @@ a.theta2.all(poissonest, pos = 1)
 
 
 ###################################################
-### code chunk number 14: rebmix-code
+### code chunk number 14: rebmix-code-10
 ###################################################
 ## EM.control object creation.
 
@@ -243,7 +243,7 @@ summary(poissonest.em)
 
 
 ###################################################
-### code chunk number 15: rebmix-code
+### code chunk number 15: rebmix-code-11
 ###################################################
 ###################################
 ##  Multivariate normal dataset  ##
@@ -283,7 +283,7 @@ mvnorm.simulated <- RNGMIX(model = "RNGMVNORM",
 
 
 ###################################################
-### code chunk number 16: rebmix-code
+### code chunk number 16: rebmix-code-12
 ###################################################
 ## Estimate number of components, component weights and component parameters.
 
@@ -297,7 +297,7 @@ mvnormest <- REBMIX(model = "REBMVNORM",
 ###################################################
 ### code chunk number 17: mvnorm-fig
 ###################################################
-plot(mvnormest)
+plot(mvnormest, family = "sans")
 
 
 ###################################################
@@ -305,23 +305,23 @@ plot(mvnormest)
 ###################################################
 mvnormclu <- RCLRMIX(model = "RCLRMVNORM", x = mvnormest)
 
-plot(mvnormclu)
+plot(mvnormclu, family = "sans")
 
 
 ###################################################
-### code chunk number 19: rebmix-code
+### code chunk number 19: rebmix-code-13
 ###################################################
 summary(mvnormest)
 
 
 ###################################################
-### code chunk number 20: rebmix-code
+### code chunk number 20: rebmix-code-14
 ###################################################
 summary(mvnormclu)
 
 
 ###################################################
-### code chunk number 21: rebmix-code
+### code chunk number 21: rebmix-code-15
 ###################################################
 ## EM.control object creation.
 
@@ -352,7 +352,7 @@ summary(mvnormest.em)
 
 
 ###################################################
-### code chunk number 22: rebmix-code
+### code chunk number 22: rebmix-code-16
 ###################################################
 ## EM.control object creation.
 
@@ -380,11 +380,11 @@ mvnorm.clu <- RCLRMIX(model = "RCLRMVNORM", x = mvnormest.cem)
 ###################################################
 ### code chunk number 23: mvnorm-clu-fig-cem
 ###################################################
-plot(mvnorm.clu)
+plot(mvnorm.clu, family = "sans")
 
 
 ###################################################
-### code chunk number 24: rebmix-code
+### code chunk number 24: rebmix-code-17
 ###################################################
 ## Create the EM.Control object to utilize one of the REBMIX&EM strategies.
 
@@ -412,7 +412,7 @@ cat("Total number of EM algorithm iterations: ",
 
 
 ###################################################
-### code chunk number 25: rebmix-code
+### code chunk number 25: rebmix-code-18
 ###################################################
 ## Create the EM.Control object to utilize one of the REBMIX&EM strategies.
 
@@ -440,7 +440,7 @@ cat("Total number of EM algorithm iterations: ",
 
 
 ###################################################
-### code chunk number 26: rebmix-code
+### code chunk number 26: rebmix-code-19
 ###################################################
 ## Create the EM.Control object to utilize one of the REBMIX&EM strategies.
 
@@ -468,7 +468,7 @@ cat("Total number of EM algorithm iterations: ",
 
 
 ###################################################
-### code chunk number 27: rebmix-code
+### code chunk number 27: rebmix-code-20
 ###################################################
 ## Create the EM.Control object to utilize one of the REBMIX&EM strategies.
 
@@ -496,7 +496,169 @@ cat("Total number of EM algorithm iterations: ",
 
 
 ###################################################
-### code chunk number 28: rebmix-code
+### code chunk number 28: rebmix-code-21
+###################################################
+## Create the EM.Control object to utilize one of the REBMIX&EM strategies.
+
+EM.stem1 <- new("EM.Control",
+  strategy = "exhaustive",
+  variant = "EM",
+  acceleration = "stem1",
+  tolerance = 1e-4,
+  maximum.iterations = 1000,
+  K = 0)
+
+## Estimate number of components, component weights and component parameters.
+
+mvnormest.em.stem1 <- REBMIX(model = "REBMVNORM",
+  Dataset = a.Dataset(mvnorm.simulated),
+  Preprocessing = "histogram",
+  cmax = 15,
+  Criterion = "BIC",
+  EMcontrol = EM.stem1)
+
+cat("Total number of EM algorithm iterations: ",
+  a.summary.EM(mvnormest.em.stem1, pos = 1, col.name = "total.iterations.nbr"),
+  ". Value of BIC: ", a.summary(mvnormest.em.stem1, pos = 1, col.name = "IC"))
+
+
+###################################################
+### code chunk number 29: rebmix-code-22
+###################################################
+## Create the EM.Control object to utilize one of the REBMIX&EM strategies.
+
+EM.stem2 <- new("EM.Control",
+  strategy = "exhaustive",
+  variant = "EM",
+  acceleration = "stem2",
+  tolerance = 1e-4,
+  maximum.iterations = 1000,
+  K = 0)
+
+## Estimate number of components, component weights and component parameters.
+
+mvnormest.em.stem2 <- REBMIX(model = "REBMVNORM",
+  Dataset = a.Dataset(mvnorm.simulated),
+  Preprocessing = "histogram",
+  cmax = 15,
+  Criterion = "BIC",
+  EMcontrol = EM.stem2)
+
+cat("Total number of EM algorithm iterations: ",
+  a.summary.EM(mvnormest.em.stem2, pos = 1, col.name = "total.iterations.nbr"),
+  ". Value of BIC: ", a.summary(mvnormest.em.stem2, pos = 1, col.name = "IC"))
+
+
+###################################################
+### code chunk number 30: rebmix-code-23
+###################################################
+## Create the EM.Control object to utilize one of the REBMIX&EM strategies.
+
+EM.stem3 <- new("EM.Control",
+  strategy = "exhaustive",
+  variant = "EM",
+  acceleration = "stem3",
+  tolerance = 1e-4,
+  maximum.iterations = 1000,
+  K = 0)
+
+## Estimate number of components, component weights and component parameters.
+
+mvnormest.em.stem3 <- REBMIX(model = "REBMVNORM",
+  Dataset = a.Dataset(mvnorm.simulated),
+  Preprocessing = "histogram",
+  cmax = 15,
+  Criterion = "BIC",
+  EMcontrol = EM.stem3)
+
+cat("Total number of EM algorithm iterations: ",
+  a.summary.EM(mvnormest.em.stem3, pos = 1, col.name = "total.iterations.nbr"),
+  ". Value of BIC: ", a.summary(mvnormest.em.stem3, pos = 1, col.name = "IC"))
+
+
+###################################################
+### code chunk number 31: rebmix-code-24
+###################################################
+## Create the EM.Control object to utilize one of the REBMIX&EM strategies.
+
+EM.square1 <- new("EM.Control",
+  strategy = "exhaustive",
+  variant = "EM",
+  acceleration = "square1",
+  tolerance = 1e-4,
+  maximum.iterations = 1000,
+  K = 0)
+
+## Estimate number of components, component weights and component parameters.
+
+mvnormest.em.square1 <- REBMIX(model = "REBMVNORM",
+  Dataset = a.Dataset(mvnorm.simulated),
+  Preprocessing = "histogram",
+  cmax = 15,
+  Criterion = "BIC",
+  EMcontrol = EM.square1)
+
+cat("Total number of EM algorithm iterations: ",
+  a.summary.EM(mvnormest.em.square1, pos = 1, col.name = "total.iterations.nbr"),
+  ". Value of BIC: ", a.summary(mvnormest.em.square1, pos = 1, col.name = "IC"))
+
+
+###################################################
+### code chunk number 32: rebmix-code-25
+###################################################
+## Create the EM.Control object to utilize one of the REBMIX&EM strategies.
+
+EM.square2 <- new("EM.Control",
+  strategy = "exhaustive",
+  variant = "EM",
+  acceleration = "square2",
+  tolerance = 1e-4,
+  maximum.iterations = 1000,
+  K = 0)
+
+## Estimate number of components, component weights and component parameters.
+
+mvnormest.em.square2 <- REBMIX(model = "REBMVNORM",
+  Dataset = a.Dataset(mvnorm.simulated),
+  Preprocessing = "histogram",
+  cmax = 15,
+  Criterion = "BIC",
+  EMcontrol = EM.square2)
+
+cat("Total number of EM algorithm iterations: ",
+  a.summary.EM(mvnormest.em.square2, pos = 1, col.name = "total.iterations.nbr"),
+  ". Value of BIC: ", a.summary(mvnormest.em.square2, pos = 1, col.name = "IC"))
+
+
+###################################################
+### code chunk number 33: rebmix-code-26
+###################################################
+## Create the EM.Control object to utilize one of the REBMIX&EM strategies.
+
+EM.square3 <- new("EM.Control",
+  strategy = "exhaustive",
+  variant = "EM",
+  acceleration = "square3",
+  tolerance = 1e-4,
+  maximum.iterations = 1000,
+  K = 0)
+
+## Estimate number of components, component weights and component parameters.
+
+mvnormest.em.square3 <- REBMIX(model = "REBMVNORM",
+  Dataset = a.Dataset(mvnorm.simulated),
+  Preprocessing = "histogram",
+  cmax = 15,
+  Criterion = "BIC",
+  EMcontrol = EM.square3)
+
+cat("Total number of EM algorithm iterations: ",
+  a.summary.EM(mvnormest.em.square3, pos = 1, col.name = "total.iterations.nbr"),
+  ". Value of BIC: ", a.summary(mvnormest.em.square3, pos = 1, col.name = "IC"))
+
+
+###################################################
+### code chunk number 34: rebmix-code-27
 ###################################################
 data(sensorlessdrive)
 
@@ -508,7 +670,7 @@ Drive <- split(p = 0.75, Dataset = sensorlessdrive, class = 4)
 
 
 ###################################################
-### code chunk number 29: rebmix-code
+### code chunk number 35: rebmix-code-28
 ###################################################
 ## Estimate number of components, component weights and component
 ## parameters for train subsets.
@@ -521,7 +683,7 @@ driveest <- REBMIX(model = "REBMVNORM",
 
 
 ###################################################
-### code chunk number 30: rebmix-code
+### code chunk number 36: rebmix-code-29
 ###################################################
 ## Selected features.
 
@@ -532,7 +694,7 @@ drivecla <- RCLSMIX(model = "RCLSMVNORM",
 
 
 ###################################################
-### code chunk number 31: rebmix-code
+### code chunk number 37: rebmix-code-30
 ###################################################
 drivecla
 
@@ -540,15 +702,15 @@ summary(drivecla)
 
 
 ###################################################
-### code chunk number 32: drive-cla-fig
+### code chunk number 38: drive-cla-fig
 ###################################################
 # Plot selected features.
 
-plot(drivecla, nrow = 3, ncol = 2)
+plot(drivecla, nrow = 3, ncol = 2, family = "sans")
 
 
 ###################################################
-### code chunk number 33: rebmix-code
+### code chunk number 39: rebmix-code-31
 ###################################################
 ## EM.control object creation.
 
@@ -580,7 +742,7 @@ summary(drivecla)
 
 
 ###################################################
-### code chunk number 34: rebmix-code
+### code chunk number 40: rebmix-code-32
 ###################################################
 data(adult)
 
@@ -594,7 +756,7 @@ adult <- as.data.frame(data.matrix(adult))
 
 
 ###################################################
-### code chunk number 35: rebmix-code
+### code chunk number 41: rebmix-code-33
 ###################################################
 ## Find numbers of levels.
 
@@ -604,7 +766,7 @@ cmax
 
 
 ###################################################
-### code chunk number 36: rebmix-code
+### code chunk number 42: rebmix-code
 ###################################################
 ## Split adult dataset into train and test subsets for two Incomes
 ## and remove Type and Income columns.
@@ -614,7 +776,7 @@ Adult <- split(p = list(type = 1, train = 2, test = 1),
 
 
 ###################################################
-### code chunk number 37: rebmix-code
+### code chunk number 43: rebmix-code-34
 ###################################################
 ## Estimate number of components, component weights and component parameters
 ## for the set of chunks 1:14.
@@ -632,7 +794,7 @@ for (i in 1:14) {
 
 
 ###################################################
-### code chunk number 38: rebmix-code
+### code chunk number 44: rebmix-code
 ###################################################
 ## Class membership prediction based upon the best first search algorithm.
 
@@ -642,7 +804,7 @@ adultcla <- BFSMIX(x = adultest,
 
 
 ###################################################
-### code chunk number 39: rebmix-code
+### code chunk number 45: rebmix-code-35
 ###################################################
 adultcla
 
@@ -650,15 +812,15 @@ summary(adultcla)
 
 
 ###################################################
-### code chunk number 40: adult-cla-fig
+### code chunk number 46: adult-cla-fig
 ###################################################
 ## Plot selected chunks.
 
-plot(adultcla, nrow = 5, ncol = 2)
+plot(adultcla, nrow = 5, ncol = 2, family = "sans")
 
 
 ###################################################
-### code chunk number 41: rebmix-code
+### code chunk number 47: rebmix-code-36
 ###################################################
 rm(list = ls())
 
