@@ -37,7 +37,7 @@ extern void RCombineComponentsMIX(void *, void *, void *, void *, void *, void *
 
 /// Panic Branislav
 extern void REMMIX(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *,
-    void *, void *, void *, void *, void *);
+    void *, void *, void *, void *, void *, void *);
 /// End
 
 extern void RRNGMVNORM(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
@@ -65,7 +65,7 @@ extern void RCombineComponentsMVNORM(void *, void *, void *, void *, void *, voi
 
 /// Panic Branislav
 extern void REMMVNORM(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *,
-    void *, void *, void *, void *);
+    void *, void *, void *, void *, void *);
 /// End
 
 extern void RvonMisesPdf(void *, void *, void *, void *, void *);
@@ -89,7 +89,7 @@ extern void RMergeLabels(void *, void *, void *, void *, void *, void *);
 
 static const R_CMethodDef CMethods[] = {
     {"RRNGMIX", (DL_FUNC) &RRNGMIX, 13},
-    {"RREBMIX", (DL_FUNC) &RREBMIX, 57},
+    {"RREBMIX", (DL_FUNC) &RREBMIX, 59},
     {"RdensKNearestNeighbourXY", (DL_FUNC) &RdensKNearestNeighbourXY, 8},
     {"RdensKDEXY", (DL_FUNC) &RdensKDEXY, 7},
     {"RdensHistogramXY", (DL_FUNC) &RdensHistogramXY, 16},
@@ -110,7 +110,7 @@ static const R_CMethodDef CMethods[] = {
     {"RInformationCriterionMIX", (DL_FUNC)&RInformationCriterionMIX, 18},
     {"RCombineComponentsMIX", (DL_FUNC) &RCombineComponentsMIX, 18},
     {"RRNGMVNORM", (DL_FUNC) &RRNGMVNORM, 12},
-    {"RREBMVNORM", (DL_FUNC) &RREBMVNORM, 56},
+    {"RREBMVNORM", (DL_FUNC) &RREBMVNORM, 58},
     {"RCLSMVNORM", (DL_FUNC) &RCLSMVNORM, 13},
     {"RCLRMVNORM", (DL_FUNC) &RCLRMVNORM, 10},
     {"RPreprocessingKNNMVNORM", (DL_FUNC) &RPreprocessingKNNMVNORM, 7},
@@ -132,8 +132,8 @@ static const R_CMethodDef CMethods[] = {
     {"RTvtNormalPdf", (DL_FUNC) &RTvtNormalPdf, 6},
     {"RMvtNormalPdf", (DL_FUNC) &RMvtNormalPdf, 7},
 /// Panic Branislav
-    {"REMMIX", (DL_FUNC)&REMMIX, 21},
-    {"REMMVNORM", (DL_FUNC)&REMMVNORM, 20},
+    {"REMMIX", (DL_FUNC)&REMMIX, 24},
+    {"REMMVNORM", (DL_FUNC)&REMMVNORM, 23},
 /// End
     {"Rfhistogram", (DL_FUNC)&Rfhistogram, 10},
     {"Rchistogram", (DL_FUNC)&Rchistogram, 10},
